==> rmap-6.7.1.tar.gz: rmap-6.7.1/test/test_domotica.py <==
#!/usr/bin/python

# Copyright (c) 2015 Paolo Patruno <p.patruno@iperbole.bologna.it>
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
# 1. Redistributions of source code must retain the above copyright notice,
#   this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in the
#   documentation and/or other materials provided with the distribution.
# 3. Neither the name of mosquitto nor the names of its
#   contributors may be used to endorse or promote products derived from
#   this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

from rmap import jsonrpc
import time

rpcproxy = jsonrpc.ServerProxy( jsonrpc.JsonRpc20(),\
                                jsonrpc.TransportMQTT( user="pat1",password="1password",mac="860719020206417",logfunc=jsonrpc.log_stdout))

rpcproxy.togglepin({"n":4,"s":False})
#time.sleep(3)
rpcproxy.togglepin({"n":4,"s":True})
#time.sleep(3)
rpcproxy.togglepin({"n":4,"s":False})
#time.sleep(3)
rpcproxy.togglepin({"n":4,"s":True})

rpcproxy.togglepin({"n":5,"s":False})
#time.sleep(3)
rpcproxy.togglepin({"n":5,"s":True})
#time.sleep(3)
rpcproxy.togglepin({"n":5,"s":False})
#time.sleep(3)
rpcproxy.togglepin({"n":5,"s":True})

#time.sleep(3)
#rpcproxy.togglepin({"n":4,"s":False},{"n":5,"s":True} )

#time.sleep(3)
#rpcproxy.togglepin({"n":4,"s":True},{"n":5,"s":False} )

==> rmap-7.5.tar.gz: rmap-7.5/test/test_domotica.py <==
#!/usr/bin/python

# Copyright (c) 2015 Paolo Patruno <p.patruno@iperbole.bologna.it>
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
# 1. Redistributions of source code must retain the above copyright notice,
#   this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in the
#   documentation and/or other materials provided with the distribution.
# 3. Neither the name of mosquitto nor the names of its
#   contributors may be used to endorse or promote products derived from
#   this software without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

import sys,os
sys.path.insert(0, "..")

from rmap import jsonrpc
import time

#mac="860719026700066"
#mac="860719020206417"

#MQTT_HOST = os.environ.get('MQTT_HOST', 'rmap.cc')
MQTT_MAC = os.environ.get('MQTT_MAC', '')
MQTT_USERNAME = os.environ.get('MQTT_USERNAME', 'rmap')
MQTT_PASSWORD = os.environ.get('MQTT_PASSWORD', 'rmap')


rpcproxy = jsonrpc.ServerProxy( jsonrpc.JsonRpc20(),\
                                jsonrpc.TransportMQTT( user=MQTT_USERNAME,password=MQTT_PASSWORD,mac=MQTT_MAC,logfunc=jsonrpc.log_stdout,timeout=10))

rpcproxy.togglepin({"n":4,"s":False})
#time.sleep(3)
rpcproxy.togglepin({"n":4,"s":True})
#time.sleep(3)
rpcproxy.togglepin({"n":4,"s":False})
#time.sleep(3)
rpcproxy.togglepin({"n":4,"s":True})

rpcproxy.togglepin({"n":5,"s":False})
#time.sleep(3)
rpcproxy.togglepin({"n":5,"s":True})
#time.sleep(3)
rpcproxy.togglepin({"n":5,"s":False})
#time.sleep(3)
rpcproxy.togglepin({"n":5,"s":True})

#time.sleep(3)
#rpcproxy.togglepin({"n":4,"s":False},{"n":5,"s":True} )

#time.sleep(3)
#rpcproxy.togglepin({"n":4,"s":True},{"n":5,"s":False} )
